summaryrefslogtreecommitdiffstats
path: root/src/app/app.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/app/app.h')
-rw-r--r--src/app/app.h12
1 files changed, 10 insertions, 2 deletions
diff --git a/src/app/app.h b/src/app/app.h
index f5383ce..f1e2c7f 100644
--- a/src/app/app.h
+++ b/src/app/app.h
@@ -283,8 +283,14 @@ public:
bool GetDebugMode();
//@}
- //! Returns the full path to a file in data directory
- std::string GetDataFilePath(const std::string &dirName, const std::string &fileName);
+ //! Returns the full path to data directory
+ std::string GetDataDirPath();
+
+ //! Returns the full path to a file in data directory given standard dir and subpath
+ std::string GetDataFilePath(DataDir dir, const std::string &subpath);
+
+ //! Returns the full path to a file in data directory given custom subpath in data dir
+ std::string GetDataFilePath(const std::string &subpath);
//! Management of language
//@{
@@ -397,6 +403,8 @@ protected:
//! Path to directory with data files
std::string m_dataPath;
+ const char* m_dataDirs[DIR_MAX];
+
//! Application language
Language m_language;